<template>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list home-list"
    v-bind="infiniteLoadingProps"
  >
    <template #renderItem="{ item }">
      <FlexJobCard
        :show-footer-left="false"
        :name="item.name"
        :age="item.age"
        :genderType="item.genderType"
        :workExperience="item.workExperience"
        :isRealName="item.isRealName"
        :arrangeCount="item.arrangeCount"
        :educationalLevel="item.educationalLevel"
        @contact="handleContact"
      >
      </FlexJobCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { FlexJobCard } from '@12333/components';
import { useUserStore } from '@/stores/modules/user';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';

defineOptions({
  name: 'InnerPage',
});

const userStore = useUserStore();

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.PageInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'creationTime', order: OrderInputType.Desc }],
      },
    };

    return flexWorkerServices.getUserContractRecordList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['flexWorkerServices/getUserContractRecordList'],
  }
);

function handleContact() {}
</script>

<style lang="scss">
@import '@/styles/common.scss';
</style>
